==> lemonade-0.0.5.tgz: package/kernel/instance.js <==
/******************************************************************************
 * Lemonade JS
 * https://lemonadejs.com
 *
 * ----
 *
 * Instance
 *
 * Creates a context for loading models / controllers / intervals and setting
 * different properties; it's not shared between requests and it's meant to
 * clear all used memory by a request on request end.
 *
 * Generates events : "end", "echo", "error". Instance creators are supposed to
 * catch and handle these events.
 *
 *****************************************************************************/

/**
 * Module dependencies
 */
var  events = require('events')
    ,util   = require('util');

/**
 * Instance
 * @constructor
 */
function Instance() {

    events.EventEmitter.call(this);

    this.id        = 'generic-' + Math.floor(Math.random() * 1000);
    this.starttime = new Date();
    this.endtime   = null;
}

/**
 * Add emitter methods to Instance
 */
util.inherits(Instance, events.EventEmitter);

/**
 * Instance end
 */
Instance.prototype.end = function(error, data) {
    this.endtime = new Date();
    this.emit('end', error, data);
};

/**
 * Instance echo
 */
Instance.prototype.echo = function(data) {
    this.emit('echo', data);
};

/**
 * Instance error
 */
Instance.prototype.error = function(data) {
    this.emit('error', data);
};

/**
 * Controller - load a controller through the Instance context
 * @param {String} path
 */
Instance.prototype.controller = function(path) {
    return this.kernel.include.call(this,

           this.kernel.appdir + '/'
         + this.kernel.config._KERNEL_DIR_CONTROLLERS + '/'
         + path

    );
};

/**
 * Interval - load an interval through the Instance context
 * @param {String} path
 */
Instance.prototype.interval = function(path) {
    return this.kernel.include.call(this,

          this.kernel.appdir + '/'
        + this.kernel.config._KERNEL_DIR_INTERVALS + '/'
        + path

    );
};

/**
 * Model - load a model through the Instance context
 * @param {String} path
 */
Instance.prototype.model = function(path) {
    return this.kernel.include.call(this,

          this.kernel.appdir + '/'
        + this.kernel.config._KERNEL_DIR_MODELS + '/'
        + path

    );
};

/**
 * Export
 */
exports = module.exports = Instance;

==> lemonade-0.1.7.tgz: package/kernel/instance.js <==
/******************************************************************************
 * Lemonade JS
 * https://lemonadejs.com
 *
 * ----
 *
 * Instance
 *
 *  Creates a context for loading models / controllers / intervals and setting
 *  different properties; it's not shared between requests and it's meant to
 *  clear all used memory by a request on request end
 *
 *  Has some basic abstract methods which instance creators should overload
 *
 *****************************************************************************/

function Instance () {
    this.id        = 'generic-' + Math.floor(Math.random() * 1000);
    this.starttime = new Date();
    this.endtime   = null;
}

/**
 * Instance end
 * @abstract
 */
Instance.prototype.end = function(error, data) {};

/**
 * Instance echo
 * @abstract
 */
Instance.prototype.echo = function(data) {};

/**
 * Instance error
 * @abstract
 */
Instance.prototype.error = function(data) {};

/**
 * Include a controller
 * @param {String} path
 */
Instance.prototype.controller = function(path) {
    return this.kernel.include.call(this,

           this.kernel.appdir + '/'
         + this.kernel.config._KERNEL_DIR_CONTROLLERS + '/'
         + path

    );
};

/**
 * Include an interval
 * @param {String} path
 */
Instance.prototype.interval = function(path) {
    return this.kernel.include.call(this,

          this.kernel.appdir + '/'
        + this.kernel.config._KERNEL_DIR_INTERVALS + '/'
        + path

    );
};

/**
 * Include a model
 * @param {String} path
 */
Instance.prototype.model = function(path) {
    return this.kernel.include.call(this,

          this.kernel.appdir + '/'
        + this.kernel.config._KERNEL_DIR_MODELS + '/'
        + path

    );
};

/**
 * Export
 */
exports = module.exports = Instance;
